OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Download" : "Download",
    "Copy link" : "Copy link",
    "Click to copy the link to your clipboard" : "Click to copy the link to your clipboard",
    "Toggle sharing" : "Toggle sharing",
    "Delete" : "Delete",
    "Rename" : "Rename",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "Close" : "Close",
    "Enabled" : "Enabled",
    "Disabled" : "Disabled",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "Address book name" : "Address book name",
    "Only these special characters are allowed: -_.!?#|()" : "Only these special characters are allowed: -_.!?#|()",
    "Address book could not be created." : "Address book could not be created.",
    "Upload new image" : "Upload new image",
    "The selected image is too big (max 1MB)" : "The selected image is too big (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent.",
    "No contacts in here" : "No contacts in here",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Title",
    "Add field …" : "Add field …",
    "Save changes" : "Save changes",
    "Address book" : "Address book",
    "Loading contacts …" : "Loading contacts …",
    "Import into" : "Import into",
    "Importing..." : "Importing...",
    "Select your addressbook" : "Select your addressbook",
    "Import is disabled because no writable address book had been found." : "Import is disabled because no writable address book had been found.",
    "No search result for {query}" : "No search result for {query}",
    "All contacts" : "All contacts",
    "Post office box" : "Post office box",
    "Postal code" : "Postcode",
    "City" : "City",
    "State or province" : "State or province",
    "Country" : "Country",
    "Address" : "Address",
    "(new group)" : "(new group)",
    "Last name" : "Surname",
    "First name" : "First-name",
    "Additional names" : "Middle names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Importing into" : "Importing into",
    "New contact" : "New contact",
    "Not grouped" : "Not grouped",
    "Sort by" : "Sort by",
    "There is no address book available to create a contact." : "There is no address book available to create a contact.",
    "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
    "Contact not found." : "Contact not found.",
    "You don't have permission to write to this addressbook." : "You don't have permission to write to this addressbook.",
    "Contact could not be created." : "Contact could not be created.",
    "No contacts in file. Only vCard files are allowed." : "No contacts in file. Only vCard files are allowed.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported.",
    "Contact could not be moved." : "Contact could not be moved.",
    "Contact could not be saved." : "Contact could not be saved.",
    "Waiting for the server to be ready…" : "Waiting for the server to be ready…",
    "Importing…" : "Importing…",
    "Display name" : "Display name",
    "Nickname" : "Nickname",
    "Detailed name" : "Detailed name",
    "Notes" : "Notes",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Home",
    "Work" : "Work",
    "Other" : "Other",
    "Groups" : "Groups",
    "Birthday" : "Birthday",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Work mobile" : "Work mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Car" : "Car",
    "Work pager" : "Work pager",
    "Social network" : "Social network",
    "Relationship" : "Relationship",
    "Specify a relationship between you and the entity represented by this vCard." : "Specify a relationship between you and the entity represented by this vCard.",
    "Spouse" : "Spouse",
    "Child" : "Child",
    "Mother" : "Mother",
    "Father" : "Father",
    "Parent" : "Parent",
    "Brother" : "Brother",
    "Sister" : "Sister",
    "Relative" : "Relative",
    "Friend" : "Friend",
    "Colleague" : "Colleague",
    "Manager" : "Manager",
    "Assistant" : "Assistant",
    "Related" : "Related",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Specify a relationship between another entity and the entity represented by this vCard.",
    "Contact" : "Contact",
    "Agent" : "Agent",
    "Emergency" : "Emergency",
    "Co-worker" : "Co-worker",
    "Gender" : "Gender",
    "Female" : "Female",
    "Male" : "Male",
    "Details" : "Details",
    "Settings" : "Settings"
},
"nplurals=2; plural=(n != 1);");
